# Attributions

This file records the attributions for all the assets used in the project.

## Icons

### favicon.ico
| URL | Icon |
| ---- | ---- |
| [Prism](https://www.flaticon.com/free-icon/pharmacy_3140343) | <img src="./img/prism.png" width="128"> |


https://www.flaticon.com/free-icon/prism_3430326